diff -pruN 1.5.1-1/CHANGES.rst 1.6-1/CHANGES.rst
--- 1.5.1-1/CHANGES.rst	2023-02-01 16:11:34.000000000 +0000
+++ 1.6-1/CHANGES.rst	2023-11-18 15:30:30.000000000 +0000
@@ -4,6 +4,12 @@ CHANGES
 
 .. towncrier release notes start
 
+1.6 (2023-11-18)
+================
+
+- Switch to ``aiohttp.web.AppKey``, and deprecate the old 'static_root_url' key.
+- Drop Python 3.7, add Python 3.12.
+
 1.5.1 (2023-02-01)
 ==================
 
diff -pruN 1.5.1-1/PKG-INFO 1.6-1/PKG-INFO
--- 1.5.1-1/PKG-INFO	2023-02-01 16:11:50.353046400 +0000
+++ 1.6-1/PKG-INFO	2023-11-18 15:30:42.625042400 +0000
@@ -1,6 +1,6 @@
 Metadata-Version: 2.1
 Name: aiohttp-jinja2
-Version: 1.5.1
+Version: 1.6
 Summary: jinja2 template renderer for aiohttp.web (http server for asyncio)
 Home-page: https://github.com/aio-libs/aiohttp_jinja2/
 Author: Andrew Svetlov
@@ -10,17 +10,19 @@ Classifier: License :: OSI Approved :: A
 Classifier: Intended Audience :: Developers
 Classifier: Programming Language :: Python
 Classifier: Programming Language :: Python :: 3
-Classifier: Programming Language :: Python :: 3.7
 Classifier: Programming Language :: Python :: 3.8
 Classifier: Programming Language :: Python :: 3.9
 Classifier: Programming Language :: Python :: 3.10
 Classifier: Programming Language :: Python :: 3.11
+Classifier: Programming Language :: Python :: 3.12
 Classifier: Development Status :: 5 - Production/Stable
 Classifier: Topic :: Internet :: WWW/HTTP
 Classifier: Framework :: AsyncIO
 Classifier: Framework :: aiohttp
-Requires-Python: >=3.7
+Requires-Python: >=3.8
 License-File: LICENSE
+Requires-Dist: aiohttp>=3.9.0
+Requires-Dist: jinja2>=3.0.0
 
 aiohttp_jinja2
 ==============
@@ -144,6 +146,12 @@ CHANGES
 
 .. towncrier release notes start
 
+1.6 (2023-11-18)
+================
+
+- Switch to ``aiohttp.web.AppKey``, and deprecate the old 'static_root_url' key.
+- Drop Python 3.7, add Python 3.12.
+
 1.5.1 (2023-02-01)
 ==================
 
diff -pruN 1.5.1-1/aiohttp_jinja2/__init__.py 1.6-1/aiohttp_jinja2/__init__.py
--- 1.5.1-1/aiohttp_jinja2/__init__.py	2023-02-01 16:11:34.000000000 +0000
+++ 1.6-1/aiohttp_jinja2/__init__.py	2023-11-18 15:30:30.000000000 +0000
@@ -1,17 +1,17 @@
 import functools
-import sys
 from typing import (
     Any,
     Awaitable,
     Callable,
     Dict,
+    Final,
     Mapping,
     Optional,
+    Protocol,
     Sequence,
     Tuple,
     TypeVar,
     Union,
-    cast,
     overload,
 )
 
@@ -19,27 +19,30 @@ import jinja2
 from aiohttp import web
 from aiohttp.abc import AbstractView
 
-if sys.version_info >= (3, 8):
-    from typing import Protocol
-else:
-    from typing_extensions import Protocol
-
-from .helpers import GLOBAL_HELPERS
+from .helpers import GLOBAL_HELPERS, static_root_key
 from .typedefs import Filters
 
-__version__ = "1.5.1"
-
-__all__ = ("setup", "get_env", "render_template", "render_string", "template")
-
+__version__ = "1.6"
 
-APP_CONTEXT_PROCESSORS_KEY = "aiohttp_jinja2_context_processors"
-APP_KEY = "aiohttp_jinja2_environment"
-REQUEST_CONTEXT_KEY = "aiohttp_jinja2_context"
+__all__ = (
+    "get_env",
+    "render_string",
+    "render_template",
+    "setup",
+    "static_root_key",
+    "template",
+)
 
 _TemplateReturnType = Awaitable[Union[web.StreamResponse, Mapping[str, Any]]]
 _SimpleTemplateHandler = Callable[[web.Request], _TemplateReturnType]
 _ContextProcessor = Callable[[web.Request], Awaitable[Dict[str, Any]]]
 
+APP_CONTEXT_PROCESSORS_KEY: Final = web.AppKey[Sequence[_ContextProcessor]](
+    "APP_CONTEXT_PROCESSORS_KEY"
+)
+APP_KEY: Final = web.AppKey[jinja2.Environment]("APP_KEY")
+REQUEST_CONTEXT_KEY: Final = "aiohttp_jinja2_context"
+
 _T = TypeVar("_T")
 _AbstractView = TypeVar("_AbstractView", bound=AbstractView)
 
@@ -67,7 +70,7 @@ class _TemplateWrapper(Protocol):
 def setup(
     app: web.Application,
     *args: Any,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
     context_processors: Sequence[_ContextProcessor] = (),
     filters: Optional[Filters] = None,
     default_helpers: bool = True,
@@ -89,23 +92,24 @@ def setup(
     return env
 
 
-def get_env(app: web.Application, *, app_key: str = APP_KEY) -> jinja2.Environment:
-    return cast(jinja2.Environment, app.get(app_key))
+def get_env(
+    app: web.Application, *, app_key: web.AppKey[jinja2.Environment] = APP_KEY
+) -> jinja2.Environment:
+    try:
+        return app[app_key]
+    except KeyError:
+        raise RuntimeError("aiohttp_jinja2.setup(...) must be called first.")
 
 
 def _render_string(
     template_name: str,
     request: web.Request,
     context: Mapping[str, Any],
-    app_key: str,
+    app_key: web.AppKey[jinja2.Environment],
 ) -> Tuple[jinja2.Template, Mapping[str, Any]]:
     env = request.config_dict.get(app_key)
     if env is None:
-        text = (
-            "Template engine is not initialized, "
-            "call aiohttp_jinja2.setup(..., app_key={}) first"
-            "".format(app_key)
-        )
+        text = "Template engine is not initialized, call aiohttp_jinja2.setup() first"
         # in order to see meaningful exception message both: on console
         # output and rendered page we add same message to *reason* and
         # *text* arguments.
@@ -129,7 +133,7 @@ def render_string(
     request: web.Request,
     context: Mapping[str, Any],
     *,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
 ) -> str:
     template, context = _render_string(template_name, request, context, app_key)
     return template.render(context)
@@ -140,7 +144,7 @@ async def render_string_async(
     request: web.Request,
     context: Mapping[str, Any],
     *,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
 ) -> str:
     template, context = _render_string(template_name, request, context, app_key)
     return await template.render_async(context)
@@ -164,7 +168,7 @@ def render_template(
     request: web.Request,
     context: Optional[Mapping[str, Any]],
     *,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
     encoding: str = "utf-8",
     status: int = 200,
 ) -> web.Response:
@@ -178,7 +182,7 @@ async def render_template_async(
     request: web.Request,
     context: Optional[Mapping[str, Any]],
     *,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
     encoding: str = "utf-8",
     status: int = 200,
 ) -> web.Response:
@@ -192,7 +196,7 @@ async def render_template_async(
 def template(
     template_name: str,
     *,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
     encoding: str = "utf-8",
     status: int = 200,
 ) -> _TemplateWrapper:
@@ -253,7 +257,6 @@ async def context_processors_middleware(
     request: web.Request,
     handler: Callable[[web.Request], Awaitable[web.StreamResponse]],
 ) -> web.StreamResponse:
-
     if REQUEST_CONTEXT_KEY not in request:
         request[REQUEST_CONTEXT_KEY] = {}
     for processor in request.config_dict[APP_CONTEXT_PROCESSORS_KEY]:
diff -pruN 1.5.1-1/aiohttp_jinja2/helpers.py 1.6-1/aiohttp_jinja2/helpers.py
--- 1.5.1-1/aiohttp_jinja2/helpers.py	2023-02-01 16:11:34.000000000 +0000
+++ 1.6-1/aiohttp_jinja2/helpers.py	2023-11-18 15:30:30.000000000 +0000
@@ -2,21 +2,19 @@
 useful context functions, see
 http://jinja.pocoo.org/docs/dev/api/#jinja2.contextfunction
 """
-import sys
-from typing import Any, Dict, Optional, Union
+import warnings
+from typing import Dict, Optional, TypedDict, Union
 
 import jinja2
 from aiohttp import web
 from yarl import URL
 
-if sys.version_info >= (3, 8):
-    from typing import TypedDict
 
-    class _Context(TypedDict, total=False):
-        app: web.Application
+class _Context(TypedDict, total=False):
+    app: web.Application
 
-else:
-    _Context = Dict[str, Any]
+
+static_root_key = web.AppKey("static_root_key", str)
 
 
 @jinja2.pass_context
@@ -61,21 +59,30 @@ def url_for(
 def static_url(context: _Context, static_file_path: str) -> str:
     """Filter for generating urls for static files.
 
-    NOTE: you'll need
-    to set app['static_root_url'] to be used as the root for the urls returned.
+    NOTE: you'll need to set app[aiohttp_jinja2.static_root_key] to be used as the
+    root for the urls returned.
 
     Usage: {{ static('styles.css') }} might become
     "/static/styles.css" or "http://mycdn.example.com/styles.css"
     """
     app = context["app"]
     try:
-        static_url = app["static_root_url"]
+        static_url = app[static_root_key]
     except KeyError:
-        raise RuntimeError(
-            "app does not define a static root url "
-            "'static_root_url', you need to set the url root "
-            "with app['static_root_url'] = '<static root>'."
-        ) from None
+        try:
+            # TODO (aiohttp 3.10+): Remove this fallback
+            static_url = app["static_root_url"]
+        except KeyError:
+            raise RuntimeError(
+                "app does not define a static root url, you need to set the url root "
+                "with app[aiohttp_jinja2.static_root_key] = '<static root>'."
+            ) from None
+        else:
+            warnings.warn(
+                "'static_root_url' is deprecated, use aiohttp_jinja2.static_root_key.",
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
     return "{}/{}".format(static_url.rstrip("/"), static_file_path.lstrip("/"))
 
 
diff -pruN 1.5.1-1/aiohttp_jinja2.egg-info/PKG-INFO 1.6-1/aiohttp_jinja2.egg-info/PKG-INFO
--- 1.5.1-1/aiohttp_jinja2.egg-info/PKG-INFO	2023-02-01 16:11:50.000000000 +0000
+++ 1.6-1/aiohttp_jinja2.egg-info/PKG-INFO	2023-11-18 15:30:42.000000000 +0000
@@ -1,6 +1,6 @@
 Metadata-Version: 2.1
 Name: aiohttp-jinja2
-Version: 1.5.1
+Version: 1.6
 Summary: jinja2 template renderer for aiohttp.web (http server for asyncio)
 Home-page: https://github.com/aio-libs/aiohttp_jinja2/
 Author: Andrew Svetlov
@@ -10,17 +10,19 @@ Classifier: License :: OSI Approved :: A
 Classifier: Intended Audience :: Developers
 Classifier: Programming Language :: Python
 Classifier: Programming Language :: Python :: 3
-Classifier: Programming Language :: Python :: 3.7
 Classifier: Programming Language :: Python :: 3.8
 Classifier: Programming Language :: Python :: 3.9
 Classifier: Programming Language :: Python :: 3.10
 Classifier: Programming Language :: Python :: 3.11
+Classifier: Programming Language :: Python :: 3.12
 Classifier: Development Status :: 5 - Production/Stable
 Classifier: Topic :: Internet :: WWW/HTTP
 Classifier: Framework :: AsyncIO
 Classifier: Framework :: aiohttp
-Requires-Python: >=3.7
+Requires-Python: >=3.8
 License-File: LICENSE
+Requires-Dist: aiohttp>=3.9.0
+Requires-Dist: jinja2>=3.0.0
 
 aiohttp_jinja2
 ==============
@@ -144,6 +146,12 @@ CHANGES
 
 .. towncrier release notes start
 
+1.6 (2023-11-18)
+================
+
+- Switch to ``aiohttp.web.AppKey``, and deprecate the old 'static_root_url' key.
+- Drop Python 3.7, add Python 3.12.
+
 1.5.1 (2023-02-01)
 ==================
 
diff -pruN 1.5.1-1/aiohttp_jinja2.egg-info/SOURCES.txt 1.6-1/aiohttp_jinja2.egg-info/SOURCES.txt
--- 1.5.1-1/aiohttp_jinja2.egg-info/SOURCES.txt	2023-02-01 16:11:50.000000000 +0000
+++ 1.6-1/aiohttp_jinja2.egg-info/SOURCES.txt	2023-11-18 15:30:42.000000000 +0000
@@ -4,6 +4,7 @@ LICENSE
 MANIFEST.in
 Makefile
 README.rst
+pytest.ini
 requirements-dev.txt
 setup.cfg
 setup.py
diff -pruN 1.5.1-1/aiohttp_jinja2.egg-info/requires.txt 1.6-1/aiohttp_jinja2.egg-info/requires.txt
--- 1.5.1-1/aiohttp_jinja2.egg-info/requires.txt	2023-02-01 16:11:50.000000000 +0000
+++ 1.6-1/aiohttp_jinja2.egg-info/requires.txt	2023-11-18 15:30:42.000000000 +0000
@@ -1,5 +1,2 @@
-aiohttp>=3.6.3
+aiohttp>=3.9.0
 jinja2>=3.0.0
-
-[:python_version < "3.8"]
-typing_extensions>=3.7.4
diff -pruN 1.5.1-1/debian/changelog 1.6-1/debian/changelog
--- 1.5.1-1/debian/changelog	2023-02-01 20:34:52.000000000 +0000
+++ 1.6-1/debian/changelog	2024-06-11 11:01:42.000000000 +0000
@@ -1,3 +1,10 @@
+aiohttp-jinja2 (1.6-1) unstable; urgency=medium
+
+  * New upstream release
+    - no longer FTBFS (closes: 1061008)
+
+ -- Piotr Ożarowski <piotr@debian.org>  Tue, 11 Jun 2024 13:01:42 +0200
+
 aiohttp-jinja2 (1.5.1-1) unstable; urgency=medium
 
   [ Debian Janitor ]
diff -pruN 1.5.1-1/docs/index.rst 1.6-1/docs/index.rst
--- 1.5.1-1/docs/index.rst	2023-02-01 16:11:34.000000000 +0000
+++ 1.6-1/docs/index.rst	2023-11-18 15:30:30.000000000 +0000
@@ -201,14 +201,13 @@ This is useful as it would allow your st
 deployment or testing with just one line.
 
 The ``static`` function has similar usage, except it requires you to
-set ``static_root_url`` on the app
+set ``app[aiohttp_jinja2.static_root_key]``.
 
-.. code-block:: ruby
+.. code-block:: python
 
     app = web.Application()
-    aiohttp_jinja2.setup(app,
-        loader=jinja2.FileSystemLoader('/path/to/templates/folder'))
-    app['static_root_url'] = '/static'
+    aiohttp_jinja2.setup(app, loader=jinja2.FileSystemLoader("/path/to/templates/folder"))
+    app[aiohttp_jinja2.static_root_key] = "/static"
 
 Then in the template::
 
diff -pruN 1.5.1-1/pytest.ini 1.6-1/pytest.ini
--- 1.5.1-1/pytest.ini	1970-01-01 00:00:00.000000000 +0000
+++ 1.6-1/pytest.ini	2023-11-18 15:30:30.000000000 +0000
@@ -0,0 +1,17 @@
+[pytest]
+addopts =
+    # show 10 slowest invocations:
+    --durations=10
+    # a bit of verbosity doesn't hurt:
+    -v
+    # report all the things == -rxXs:
+    -ra
+    # show values of the local vars in errors:
+    --showlocals
+    # coverage reports
+    --cov=aiohttp_jinja2/ --cov=tests/ --cov-report term
+asyncio_mode = auto
+filterwarnings =
+    error
+testpaths = tests/
+xfail_strict = true
diff -pruN 1.5.1-1/requirements-dev.txt 1.6-1/requirements-dev.txt
--- 1.5.1-1/requirements-dev.txt	2023-02-01 16:11:34.000000000 +0000
+++ 1.6-1/requirements-dev.txt	2023-11-18 15:30:30.000000000 +0000
@@ -1,10 +1,10 @@
 -r requirements.txt
 
-flake8==6.0.0
+flake8==6.1.0
 flake8-bandit==4.1.1
-flake8-bugbear==23.1.20
+flake8-bugbear==23.9.16
 flake8-import-order==0.18.2
-flake8-requirements==1.7.6
-mypy==0.991; implementation_name=="cpython"
-pre-commit==3.0.2
-sphinx==6.1.3
+flake8-requirements==2.0.1
+mypy==1.7.0; implementation_name=="cpython"
+pre-commit==3.5.0
+sphinx==7.2.6
diff -pruN 1.5.1-1/setup.cfg 1.6-1/setup.cfg
--- 1.5.1-1/setup.cfg	2023-02-01 16:11:50.353046400 +0000
+++ 1.6-1/setup.cfg	2023-11-18 15:30:42.625042400 +0000
@@ -5,16 +5,6 @@ multi_line_output = 3
 force_grid_wrap = 0
 combine_as_imports = True
 
-[tool:pytest]
-addopts = --cov=aiohttp_jinja2 --cov-report xml --cov-report html --cov-report term
-asyncio_mode = auto
-junit_suite_name = aiohttp_test_suite
-filterwarnings = 
-	error
-testpaths = tests/
-junit_family = xunit2
-xfail_strict = true
-
 [egg_info]
 tag_build = 
 tag_date = 0
diff -pruN 1.5.1-1/setup.py 1.6-1/setup.py
--- 1.5.1-1/setup.py	2023-02-01 16:11:34.000000000 +0000
+++ 1.6-1/setup.py	2023-11-18 15:30:30.000000000 +0000
@@ -27,13 +27,6 @@ def read(f):
     return Path(__file__).with_name(f).read_text()
 
 
-install_requires = [
-    "aiohttp>=3.6.3",
-    "jinja2>=3.0.0",
-    'typing_extensions>=3.7.4; python_version<"3.8"',
-]
-
-
 setup(
     name="aiohttp-jinja2",
     version=version,
@@ -44,11 +37,11 @@ setup(
         "Intended Audience :: Developers",
         "Programming Language :: Python",
         "Programming Language :: Python :: 3",
-        "Programming Language :: Python :: 3.7",
         "Programming Language :: Python :: 3.8",
         "Programming Language :: Python :: 3.9",
         "Programming Language :: Python :: 3.10",
         "Programming Language :: Python :: 3.11",
+        "Programming Language :: Python :: 3.12",
         "Development Status :: 5 - Production/Stable",
         "Topic :: Internet :: WWW/HTTP",
         "Framework :: AsyncIO",
@@ -59,7 +52,7 @@ setup(
     url="https://github.com/aio-libs/aiohttp_jinja2/",
     license="Apache 2",
     packages=["aiohttp_jinja2"],
-    python_requires=">=3.7",
-    install_requires=install_requires,
+    python_requires=">=3.8",
+    install_requires=("aiohttp>=3.9.0", "jinja2>=3.0.0"),
     include_package_data=True,
 )
diff -pruN 1.5.1-1/tests/test_context_processors.py 1.6-1/tests/test_context_processors.py
--- 1.5.1-1/tests/test_context_processors.py	2023-02-01 16:11:34.000000000 +0000
+++ 1.6-1/tests/test_context_processors.py	2023-11-18 15:30:30.000000000 +0000
@@ -1,4 +1,4 @@
-from typing import Dict, Union
+from typing import Dict, Tuple, Union
 
 import jinja2
 from aiohttp import web
@@ -22,10 +22,11 @@ async def test_context_processors(aiohtt
     async def processor(request: web.Request) -> Dict[str, Union[str, int]]:
         return {"foo": 1, "bar": "should be overwriten"}
 
-    app["aiohttp_jinja2_context_processors"] = (
+    f: Tuple[aiohttp_jinja2._ContextProcessor, ...] = (
         aiohttp_jinja2.request_processor,
         processor,
     )
+    app[aiohttp_jinja2.APP_CONTEXT_PROCESSORS_KEY] = f
 
     app.router.add_get("/", func)
 
@@ -56,7 +57,7 @@ async def test_nested_context_processors
     async def subprocessor(request):
         return {"foo": 1, "bar": "should be overwriten"}
 
-    subapp["aiohttp_jinja2_context_processors"] = (
+    subapp[aiohttp_jinja2.APP_CONTEXT_PROCESSORS_KEY] = (
         aiohttp_jinja2.request_processor,
         subprocessor,
     )
@@ -69,7 +70,7 @@ async def test_nested_context_processors
     async def processor(request):
         return {"baz": 5}
 
-    app["aiohttp_jinja2_context_processors"] = (
+    app[aiohttp_jinja2.APP_CONTEXT_PROCESSORS_KEY] = (
         aiohttp_jinja2.request_processor,
         processor,
     )
@@ -129,7 +130,6 @@ async def test_context_processors_new_se
 
 
 async def test_context_not_tainted(aiohttp_client):
-
     global_context = {"version": 1}
 
     @aiohttp_jinja2.template("tmpl.jinja2")
diff -pruN 1.5.1-1/tests/test_jinja_globals.py 1.6-1/tests/test_jinja_globals.py
--- 1.5.1-1/tests/test_jinja_globals.py	2023-02-01 16:11:34.000000000 +0000
+++ 1.6-1/tests/test_jinja_globals.py	2023-11-18 15:30:30.000000000 +0000
@@ -20,7 +20,7 @@ async def test_url(aiohttp_client):
         return {}
 
     async def other(request):
-        return
+        """Dummy handler."""
 
     app = web.Application()
     aiohttp_jinja2.setup(
@@ -66,7 +66,7 @@ async def test_url_int_param(aiohttp_cli
         return {}
 
     async def other(request):
-        return
+        """Dummy handler."""
 
     app = web.Application()
     aiohttp_jinja2.setup(
@@ -96,7 +96,7 @@ async def test_url_param_forbidden_type(
         return web.Response()
 
     async def other(request):
-        return
+        """Dummy handler."""
 
     app = web.Application()
     aiohttp_jinja2.setup(
@@ -141,7 +141,7 @@ async def test_static(aiohttp_client):
         app, loader=jinja2.DictLoader({"tmpl.jinja2": "{{ static('whatever.js') }}"})
     )
 
-    app["static_root_url"] = "/static"
+    app[aiohttp_jinja2.static_root_key] = "/static"
     app.router.add_route("GET", "/", index)
     client = await aiohttp_client(app)
 
@@ -153,7 +153,7 @@ async def test_static(aiohttp_client):
 
 async def test_static_var_missing(aiohttp_client, caplog):
     async def index(request):
-        with pytest.raises(RuntimeError, match="static_root_url"):
+        with pytest.raises(RuntimeError, match="static_root_key"):
             aiohttp_jinja2.render_template("tmpl.jinja2", request, {})
         return web.Response()
 
@@ -166,4 +166,4 @@ async def test_static_var_missing(aiohtt
     client = await aiohttp_client(app)
 
     resp = await client.get("/")
-    assert 200 == resp.status  # static_root_url is not set
+    assert 200 == resp.status  # static_root_key is not set
diff -pruN 1.5.1-1/tests/test_simple_renderer.py 1.6-1/tests/test_simple_renderer.py
--- 1.5.1-1/tests/test_simple_renderer.py	2023-02-01 16:11:34.000000000 +0000
+++ 1.6-1/tests/test_simple_renderer.py	2023-11-18 15:30:30.000000000 +0000
@@ -107,11 +107,7 @@ async def test_render_not_initialized():
     app.router.add_route("GET", "/", func)
 
     req = make_mocked_request("GET", "/", app=app)
-    msg = (
-        "Template engine is not initialized, "
-        "call aiohttp_jinja2.setup(..., app_key={}"
-        ") first".format(aiohttp_jinja2.APP_KEY)
-    )
+    msg = "Template engine is not initialized, call aiohttp_jinja2.setup() first"
 
     with pytest.raises(web.HTTPInternalServerError) as ctx:
         await func(req)
